# Implicit Concept Dataset (ICD)

This repo releases data introduced in our paper: [Implicit Concept Removal of Diffusion Models](https://arxiv.org/abs/2310.05873)



Text-to-image (T2I) diffusion models often inadvertently generate unwanted concepts such as watermarks and unsafe images. These concepts, termed as the "implicit concepts", could be unintentionally learned during training and then be generated uncontrollably during inference. Existing removal methods still struggle to eliminate implicit concepts primarily due to their dependency on the model's ability to recognize concepts it actually can not discern. To address this, we utilize the intrinsic geometric characteristics of implicit concepts and present the Geom-Erasing, a novel concept removal method based on the geometric-driven control. Specifically, once an unwanted implicit concept is identified, we integrate the existence and geometric information of the concept into the text prompts with the help of an accessible classifier or detector model. Subsequently, the model is optimized to identify and disentangle this information, which is then adopted as negative prompts during generation. Moreover, we introduce the Implicit Concept Dataset (ICD), a novel image-text dataset imbued with three typical implicit concepts (i.e., QR codes, watermarks, and text), reflecting real-life situations where implicit concepts are easily injected. Geom-Erasing effectively mitigates the generation of implicit concepts, achieving the state-of-the-art results on the Inappropriate Image Prompts (I2P) and our challenging Implicit Concept Dataset (ICD) benchmarks.



![main_method](./assets/main_method.png)



## Dataset Release

We release two datasets: ICD-QR & ICD-Text for academic use. To prevent the potential risk of hide content infringement through Geom-Erasing, we decide not to open-source the ICD-watermark. Contact us if you needs any help.

![dataset_images_more](./assets/dataset_images_more.png)



### ICD-QR

Real QR codes are pasted on the Pokemon dataset. The total dataset contains 802 image-text pairs, which is divided into two portions: 80% for fine-tuning (ICD-QR/train.json), and the remaining 20% for testing (ICD-QR/test.json). In the training subset, QR codes are pasted to 25% of the images, with QR code lengths varying from 1/4 to 1/2 of the image length, placed randomly, occasionally overlapping with the original content to resemble real-world scenarios. Importantly, test images remain QR code-free for evaluation. 



### ICD-Text

 The training dataset we used is provided by [LAION-Glyph-1M](https://github.com/AIGText/GlyphControl-release). Please follow their download instruction. It comprises 1M samples, with each image containing text. For the evaluation dataset, additional 2k text-free images are collected from LAION (ICD-Text/laion_notext_eval/test.json). 